Arctic Tern: Simple Postgres migrations for Python
==================================================
.. image:: https://travis-ci.org/ConvergysLabs/arctic-tern.svg?branch=master
    :target: https://travis-ci.org/ConvergysLabs/arctic-tern

.. image:: https://codecov.io/github/ConvergysLabs/arctic-tern/coverage.svg?branch=master
    :target: https://codecov.io/github/ConvergysLabs/arctic-tern
    :alt: codecov.io

.. image:: https://upload.wikimedia.org/wikipedia/commons/2/29/2009_07_02_-_Arctic_tern_on_Farne_Islands_-_The_blue_rope_demarcates_the_visitors%27_path.JPG
    :target: https://en.wikipedia.org/wiki/Arctic_tern

You can be strongly migratory, too!

Feature Support
---------------

- Plain SQL update scripts
- Timestamped update scripts
- Code-level integration (no CLI needed)

Arctic Tern officially supports Python 3.6+

Installation
------------

To install Arctic Tern, simply `pip install arctic-tern`

Documentation
-------------

Documentation is good!  We should get some.


How to Contribute
-----------------

This would also be good.
